@@ -19,7 +19,7 @@ use Types::Standard qw/Str Int Bool HashRef/;
 use Type::Utils;
 use Module::Pluggable require => 1, search_path => ['Group::Git::Cmd', 'Group::Git::Taggers'];
 
-our $VERSION = version->new('0.5.5');
+our $VERSION = version->new('0.5.6');
 our $AUTOLOAD;
 
 has conf => (
@@ -76,7 +76,7 @@ sub _repos {
 
     while ( my $file = shift @files ) {
         next unless -d $file;
-        my $config = $file->file('.git', 'config');
+        my $config = $file->path('.git', 'config');
 
         if ( !-f $config ) {
             push @files, $file->children if $self->recurse && $file->basename ne '.git';
@@ -144,7 +144,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.5.5.
+This documentation refers to Group::Git version 0.5.6.
 
 =head1 SYNOPSIS
 
