@@ -15,7 +15,7 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.5.5');
+our $VERSION = version->new('0.5.6');
 
 requires 'repos';
 requires 'verbose';
@@ -70,10 +70,7 @@ sub pull {
     my $cmd;
     my $dir;
 
-    if ( !$repo->git ) {
-        return;
-    }
-    elsif ( -d $name ) {
+    if ( -d $name ) {
         $dir = $name;
         my @args = map {
                 $opt->opt->{$_} eq '0'   ? "--no-$_"
@@ -83,9 +80,12 @@ sub pull {
             keys %{ $opt->opt };
         $cmd = join ' ', 'git', map { $self->shell_quote } $type, @args, @ARGV;
     }
-    else {
+    elsif ( $repo->git ) {
         $cmd = join ' ', 'git', 'clone', map { $self->shell_quote } $repo->git, $name;
     }
+    else {
+        return;
+    }
 
     local $CWD = $dir if $dir;
     warn "$cmd\n" if $self->verbose > 1;
@@ -108,7 +108,7 @@ Group::Git::Cmd::Pull - Pull latest version of all repositories or clone any tha
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Pull version 0.5.5.
+This documentation refers to Group::Git::Cmd::Pull version 0.5.6.
 
 
 =head1 SYNOPSIS
